# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import winrt.system
from winui3._winui3_microsoft_ui_xaml_media_media3d import (
    Matrix3D,
    CompositeTransform3D,
    Matrix3DHelper,
    PerspectiveTransform3D,
    Transform3D,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winui3._winui3_microsoft_ui_xaml_media_media3d import (
        Transform3D_Static,
    )

__all__ = [
    "Matrix3D",
    "CompositeTransform3D",
    "Matrix3DHelper",
    "PerspectiveTransform3D",
    "Transform3D",
]

